AsyncResult<S extends Object> typedef

AsyncResult<S extends Object> = AsyncResultDart<S, Exception>

A typedef for an asynchronous Result, simplifying the usage of AsyncResultDart with Exception as the default failure type.

This is used to represent asynchronous operations that can succeed with a value of type S or fail with an Exception.

Implementation

typedef AsyncResult<S extends Object> = AsyncResultDart<S, Exception>;