CleanupFailureEvent class final
Runtime-observer projection of an existing cleanup diagnostic.
Constructors
- CleanupFailureEvent({required RuntimeEventContext context, required DateTime timestamp, required CleanupFailureDiagnostic diagnostic})
-
const
Properties
- context → RuntimeEventContext
-
final
- diagnostic → CleanupFailureDiagnostic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited