call<T extends Object> abstract method
Resolve a dependency at the point where the code uses it.
Implementation
T call<T extends Object>([ServiceKey<T>? key]);
Resolve a dependency at the point where the code uses it.
T call<T extends Object>([ServiceKey<T>? key]);