ExecutionStartEvent class final

Emitted synchronously immediately before an Effect runner starts.

Constructors

ExecutionStartEvent({required RuntimeEventContext context, required DateTime startedAt})
const

Properties

context RuntimeEventContext
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited