mapFold<G extends Object, W extends Object> abstract method

ResultDart<G, W> mapFold<G extends Object, W extends Object>(
  1. G onSuccess(
    1. S success
    ),
  2. W onFailure(
    1. F failure
    )
)

Returns a new Result, mapping any Success value using the given transformation and unwrapping the produced Result. Returns a new Result, mapping any Error value using the given transformation and unwrapping the produced Result.

Implementation

ResultDart<G, W> mapFold<G extends Object, W extends Object>(
  G Function(S success) onSuccess,
  W Function(F failure) onFailure,
);