RuntimeObserverError class final

A callback failure that was isolated from execution semantics.

Constructors

RuntimeObserverError({required RuntimeObserver observer, required RuntimeObserverCallback callback, required Object event, required Object error, required StackTrace stackTrace})
const

Properties

callback RuntimeObserverCallback
final
error Object
final
event Object
final
hashCode int
The hash code for this object.
no setterinherited
observer RuntimeObserver
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited