ServiceAcquireEvent class final

Describes acquisition of one Module or Effect resource.

Constructors

ServiceAcquireEvent({required RuntimeEventContext context, required Type serviceType, required String? serviceKey, required ResourceAcquisitionSource source, required DateTime startedAt, required DateTime completedAt, required Duration duration, required Object? error, required StackTrace? stackTrace})
const

Properties

completedAt DateTime
final
context RuntimeEventContext
final
duration Duration
final
error Object?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceKey String?
final
serviceType Type
final
source ResourceAcquisitionSource
final
stackTrace StackTrace?
final
startedAt DateTime
final
succeeded bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited