mapFold<G extends Object, W extends Object> abstract method
ResultDart<G, W>
mapFold<G extends Object, W extends Object>(
- G onSuccess(
- S success
- W onFailure(
- F failure
Returns a new Result, mapping any Success value
using the given transformation and unwrapping the produced Result.
Returns a new Result, mapping any Error value
using the given transformation and unwrapping the produced Result.
Implementation
ResultDart<G, W> mapFold<G extends Object, W extends Object>(
G Function(S success) onSuccess,
W Function(F failure) onFailure,
);