recover<R extends Object> abstract method
Returns the encapsulated Result of the given transform function
applied to the encapsulated a Failure or the original
encapsulated value if it is success.
Implementation
ResultDart<S, R> recover<R extends Object>(
ResultDart<S, R> Function(F failure) onFailure,
);