zip<S2 extends Object> abstract method
Combines this Result with other into a single Result
containing a Record of both success values.
If either is a Failure, returns the first Failure encountered.
Implementation
ResultDart<(S, S2), F> zip<S2 extends Object>(ResultDart<S2, F> other);