Services class final
A read-only, callable view of the services available in a Runtime.
This type is primarily useful at composition boundaries such as
Binding.resource. Business code should normally request services through
the use value received by Effect.result.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call<
T extends Object> ([ServiceKey< T> ? key]) → T - Resolve a service by type or by a typed ServiceKey.
-
get<
T extends Object> ([ServiceKey< T> ? key]) → T - Named equivalent of call for discoverability.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited